ApiConfig class
Constructors
-
ApiConfig({required String baseUrl, bool enableAutoRefresh = true, void onSessionExpired()?, RefreshConfig? refreshConfig, List<
Interceptor> ? interceptors, void onError(DioException e, RequestOptions request)?, bool enableLogs = true, Map<String, dynamic> ? headers, bool allowBadCertificates = false}) -
const
Properties
- allowBadCertificates → bool
-
final
- baseUrl → String
-
final
- enableAutoRefresh → bool
-
final
- enableLogs → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, dynamic> ? -
final
-
interceptors
→ List<
Interceptor> ? -
final
- onError → void Function(DioException e, RequestOptions request)?
-
final
- onSessionExpired → void Function()?
-
final
- refreshConfig → RefreshConfig?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited